@@ -133,7 +133,11 @@ int ca_cli_callback_status (int argc, char **argv)
 
 int __ca_cli_callback_listcert_aux (void *pArg, int argc, char **argv, char **columnNames)
 {
+#ifndef WIN32
 	struct tm tmp;
+#else
+	struct tm *tmp = NULL;
+#endif
 	time_t aux_date;
 	gchar model_time_str[100];
 
@@ -163,19 +167,27 @@ int __ca_cli_callback_listcert_aux (void *pArg, int argc, char **argv, char **co
 	if (aux_date == 0) {
 		printf (Q_("CertList Activation|\t"));
 	} else {	
+#ifndef WIN32	
 		gmtime_r (&aux_date, &tmp);
-	
 		strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &tmp);
+#else
+		tmp = gmtime (&aux_date);
+		strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), tmp);
+#endif
 		printf (Q_("CertList Activation|%s\t"), model_time_str);
 	}
 
 	aux_date = atol(argv[CA_FILE_CERT_COLUMN_EXPIRATION]);
 	if (aux_date == 0) {
 		printf (Q_("CertList Expiration|\t"));
-	} else {	
+	} else {
+#ifndef WIN32
 		gmtime_r (&aux_date, &tmp);
-	
 		strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &tmp);
+#else
+		tmp = gmtime (&aux_date);
+		strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), tmp);
+#endif
 		printf (Q_("CertList Expiration|%s\t"), model_time_str);
 	}
 
@@ -184,9 +196,13 @@ int __ca_cli_callback_listcert_aux (void *pArg, int argc, char **argv, char **co
 		if (aux_date == 0) {
 			printf (Q_("CertList Revocation|\n"));
 		} else {	
-			gmtime_r (&aux_date, &tmp);
-			
+#ifndef WIN32
+			gmtime_r (&aux_date, &tmp);		
 			strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &tmp);
+#else
+			tmp = gmtime (&aux_date);
+			strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), tmp);
+#endif
 			printf (Q_("CertList Revocation|%s\n"), model_time_str);
 		}
 	} else {
@@ -288,28 +304,28 @@ int ca_cli_callback_addcsr (int argc, char **argv)
 
                 tlscert = tls_parse_cert_pem (pem);
 
-                if (ca_file_policy_get (ca_id, "C_INHERIT")) {
-                        c_force_same = ca_file_policy_get (ca_id, "C_FORCE_SAME");
+                if (ca_file_policy_get_int (ca_id, "C_INHERIT")) {
+                        c_force_same = ca_file_policy_get_int (ca_id, "C_FORCE_SAME");
 			csr_creation_data->country = g_strdup (tlscert->c);
                 } 
 		
-		if (ca_file_policy_get (ca_id, "ST_INHERIT")) {
-			st_force_same = ca_file_policy_get (ca_id, "ST_FORCE_SAME");
+		if (ca_file_policy_get_int (ca_id, "ST_INHERIT")) {
+			st_force_same = ca_file_policy_get_int (ca_id, "ST_FORCE_SAME");
 			csr_creation_data->state = g_strdup (tlscert->st);
 		}
 
-		if (ca_file_policy_get (ca_id, "L_INHERIT")) {
-			l_force_same = ca_file_policy_get (ca_id, "L_FORCE_SAME");
+		if (ca_file_policy_get_int (ca_id, "L_INHERIT")) {
+			l_force_same = ca_file_policy_get_int (ca_id, "L_FORCE_SAME");
 			csr_creation_data->city = g_strdup (tlscert->l);
 		}
 
-		if (ca_file_policy_get (ca_id, "O_INHERIT")) {
-			o_force_same = ca_file_policy_get (ca_id, "O_FORCE_SAME");
+		if (ca_file_policy_get_int (ca_id, "O_INHERIT")) {
+			o_force_same = ca_file_policy_get_int (ca_id, "O_FORCE_SAME");
 			csr_creation_data->org = g_strdup (tlscert->o);
 		}
 
-		if (ca_file_policy_get (ca_id, "OU_INHERIT")) {
-			ou_force_same = ca_file_policy_get (ca_id, "OU_FORCE_SAME");
+		if (ca_file_policy_get_int (ca_id, "OU_INHERIT")) {
+			ou_force_same = ca_file_policy_get_int (ca_id, "OU_FORCE_SAME");
 			csr_creation_data->ou = g_strdup (tlscert->ou);
 		}
 
@@ -431,7 +447,11 @@ int ca_cli_callback_addca (int argc, char **argv)
 
 	time_t tmp;
 	struct tm * expiration_time;
+#ifndef WIN32
 	struct tm timer;
+#else
+	struct tm *timer = NULL;
+#endif
 	char model_time_str[100];
 
 	ca_creation_data = g_new0 (TlsCreationData, 1);
@@ -514,12 +534,19 @@ int ca_cli_callback_addca (int argc, char **argv)
 		ca_creation_data->activation = tmp;
 	
 		expiration_time = g_new (struct tm,1);
-		localtime_r (&tmp, expiration_time);      
+
+#ifndef WIN32
+		localtime_r (&tmp, expiration_time);
+#else
+		expiration_time = localtime (&tmp);
+#endif
 		expiration_time->tm_mon = expiration_time->tm_mon + ca_creation_data->key_months_before_expiration;
 		expiration_time->tm_year = expiration_time->tm_year + (expiration_time->tm_mon / 12);
 		expiration_time->tm_mon = expiration_time->tm_mon % 12;	
 		ca_creation_data->expiration = mktime(expiration_time);
+#ifndef WIN32
 		g_free (expiration_time);
+#endif
 
 		printf (_("These are the provided new CA properties:\n"));
 
@@ -543,12 +570,22 @@ int ca_cli_callback_addca (int argc, char **argv)
 		printf (_("\tKey bitlength: %d\n"), ca_creation_data->key_bitlength);
 		printf (_("Validity\n"));
 		printf (_("Validity:\n"));
+#ifndef WIN32
 		gmtime_r (&ca_creation_data->activation, &timer);
-		strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &timer);	
+		strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &timer);
+#else
+		timer = gmtime (&ca_creation_data->activation);
+		strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), timer);
+#endif		
 		printf (_("\tActivated on: %s\n"), model_time_str);
 		
+#ifndef WIN32
 		gmtime_r (&ca_creation_data->expiration, &timer);
 		strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &timer);	
+#else
+		timer = gmtime (&ca_creation_data->expiration);
+		strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), timer);	
+#endif
 		printf (_("\tExpires on: %s\n"), model_time_str);
 
 		change_data = dialog_ask_for_confirmation (NULL, _("Do you want to change anything? Yes/[No] "), FALSE);
@@ -771,115 +808,113 @@ int ca_cli_callback_sign (int argc, char **argv)
 
 	cert_creation_data->key_months_before_expiration = dialog_ask_for_number (_("Introduce number of months before expiration of the new certificate (0 to cancel)"),
 									      0,
-									      ca_file_policy_get (ca_id, "MONTHS_TO_EXPIRE"), 
-									      ca_file_policy_get (ca_id, "MONTHS_TO_EXPIRE"));
+									      ca_file_policy_get_int (ca_id, "MONTHS_TO_EXPIRE"), 
+									      ca_file_policy_get_int (ca_id, "MONTHS_TO_EXPIRE"));
 	
 	if (cert_creation_data->key_months_before_expiration == 0) {
 		g_free (cert_creation_data);
 		printf (_("Operation cancelled.\n"));
 	}
 
-	printf (_("The certificate will be generated with the following uses and purposes:\n"));
+	cert_creation_data->ca = ca_file_policy_get_int (ca_id, "CA");
+	cert_creation_data->crl_signing = ca_file_policy_get_int (ca_id, "CRL_SIGN");
+	cert_creation_data->digital_signature = ca_file_policy_get_int (ca_id, "DIGITAL_SIGNATURE");
+	cert_creation_data->data_encipherment =  ca_file_policy_get_int (ca_id, "DATA_ENCIPHERMENT");
+	cert_creation_data->key_encipherment = ca_file_policy_get_int (ca_id, "KEY_ENCIPHERMENT");
+	cert_creation_data->non_repudiation = ca_file_policy_get_int (ca_id, "NON_REPUDIATION");
+	cert_creation_data->key_agreement = ca_file_policy_get_int (ca_id, "KEY_AGREEMENT");
 
-	cert_creation_data->ca = ca_file_policy_get (ca_id, "CA");
-	cert_creation_data->crl_signing = ca_file_policy_get (ca_id, "CRL_SIGN");
-	cert_creation_data->digital_signature = ca_file_policy_get (ca_id, "DIGITAL_SIGNATURE");
-	cert_creation_data->data_encipherment =  ca_file_policy_get (ca_id, "DATA_ENCIPHERMENT");
-	cert_creation_data->key_encipherment = ca_file_policy_get (ca_id, "KEY_ENCIPHERMENT");
-	cert_creation_data->non_repudiation = ca_file_policy_get (ca_id, "NON_REPUDIATION");
-	cert_creation_data->key_agreement = ca_file_policy_get (ca_id, "KEY_AGREEMENT");
-
-	cert_creation_data->email_protection = ca_file_policy_get (ca_id, "EMAIL_PROTECTION");
-	cert_creation_data->code_signing = ca_file_policy_get (ca_id, "CODE_SIGNING");
-	cert_creation_data->web_client =  ca_file_policy_get (ca_id, "TLS_WEB_CLIENT");
-	cert_creation_data->web_server = ca_file_policy_get (ca_id, "TLS_WEB_SERVER");
-	cert_creation_data->time_stamping = ca_file_policy_get (ca_id, "TIME_STAMPING");
-	cert_creation_data->ocsp_signing = ca_file_policy_get (ca_id, "OCSP_SIGNING");
-	cert_creation_data->any_purpose = ca_file_policy_get (ca_id, "ANY_PURPOSE");
+	cert_creation_data->email_protection = ca_file_policy_get_int (ca_id, "EMAIL_PROTECTION");
+	cert_creation_data->code_signing = ca_file_policy_get_int (ca_id, "CODE_SIGNING");
+	cert_creation_data->web_client =  ca_file_policy_get_int (ca_id, "TLS_WEB_CLIENT");
+	cert_creation_data->web_server = ca_file_policy_get_int (ca_id, "TLS_WEB_SERVER");
+	cert_creation_data->time_stamping = ca_file_policy_get_int (ca_id, "TIME_STAMPING");
+	cert_creation_data->ocsp_signing = ca_file_policy_get_int (ca_id, "OCSP_SIGNING");
+	cert_creation_data->any_purpose = ca_file_policy_get_int (ca_id, "ANY_PURPOSE");
 
 	printf (_("The new certificate will be created with the following uses and purposes:\n"));
 	__ca_cli_callback_show_uses_and_purposes (cert_creation_data);
 	
 	while (dialog_ask_for_confirmation (NULL, _("Do you want to change any property of the new certificate? Yes/[No] "), FALSE)) {
 
-		if (ca_file_policy_get (ca_id, "CA")) {
+		if (ca_file_policy_get_int (ca_id, "CA")) {
 			cert_creation_data->ca = dialog_ask_for_confirmation (NULL, _("* Enable Certification Authority use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Certification Authority use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "CRL_SIGN")) {
+		if (ca_file_policy_get_int (ca_id, "CRL_SIGN")) {
 			cert_creation_data->crl_signing = dialog_ask_for_confirmation (NULL, _("* Enable CRL Signing? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* CRL signing use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "DIGITAL_SIGNATURE")) {
+		if (ca_file_policy_get_int (ca_id, "DIGITAL_SIGNATURE")) {
 			cert_creation_data->digital_signature = dialog_ask_for_confirmation (NULL, _("* Enable Digital Signature use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Digital Signature use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "DATA_ENCIPHERMENT")) {
+		if (ca_file_policy_get_int (ca_id, "DATA_ENCIPHERMENT")) {
 			cert_creation_data->data_encipherment = dialog_ask_for_confirmation (NULL, _("Enable Data Encipherment use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Data Encipherment use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "KEY_ENCIPHERMENT")) {
+		if (ca_file_policy_get_int (ca_id, "KEY_ENCIPHERMENT")) {
 			cert_creation_data->key_encipherment = dialog_ask_for_confirmation (NULL, _("Enable Key Encipherment use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Key Encipherment use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "NON_REPUDIATION")) {
+		if (ca_file_policy_get_int (ca_id, "NON_REPUDIATION")) {
 			cert_creation_data->non_repudiation = dialog_ask_for_confirmation (NULL, _("Enable Non Repudiation use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Non Repudiation use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "KEY_AGREEMENT")) {
+		if (ca_file_policy_get_int (ca_id, "KEY_AGREEMENT")) {
 			cert_creation_data->key_agreement = dialog_ask_for_confirmation (NULL, _("Enable Key Agreement use? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Key Agreement use disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "EMAIL_PROTECTION")) {
+		if (ca_file_policy_get_int (ca_id, "EMAIL_PROTECTION")) {
 			cert_creation_data->email_protection = dialog_ask_for_confirmation (NULL, _("Enable Email Protection purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Email Protection purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "CODE_SIGNING")) {
+		if (ca_file_policy_get_int (ca_id, "CODE_SIGNING")) {
 			cert_creation_data->code_signing = dialog_ask_for_confirmation (NULL, _("Enable Code Signing purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Code Signing purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "TLS_WEB_CLIENT")) {
+		if (ca_file_policy_get_int (ca_id, "TLS_WEB_CLIENT")) {
 			cert_creation_data->web_client = dialog_ask_for_confirmation (NULL, _("Enable TLS Web Client purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* TLS Web Client purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "TLS_WEB_SERVER")) {
+		if (ca_file_policy_get_int (ca_id, "TLS_WEB_SERVER")) {
 			cert_creation_data->web_server = dialog_ask_for_confirmation (NULL, _("Enable TLS Web Server purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* TLS Web Server purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "TIME_STAMPING")) {
+		if (ca_file_policy_get_int (ca_id, "TIME_STAMPING")) {
 			cert_creation_data->time_stamping = dialog_ask_for_confirmation (NULL, _("Enable Time Stamping purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Time Stamping purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "OCSP_SIGNING")) {
+		if (ca_file_policy_get_int (ca_id, "OCSP_SIGNING")) {
 			cert_creation_data->ocsp_signing = dialog_ask_for_confirmation (NULL, _("Enable OCSP Signing purpose? [Yes]/No "), TRUE);		} else {
 			printf (_("* OCSP Signing purpose disabled by policy\n"));
 		}
 
-		if (ca_file_policy_get (ca_id, "ANY_PURPOSE")) {
+		if (ca_file_policy_get_int (ca_id, "ANY_PURPOSE")) {
 			cert_creation_data->any_purpose = dialog_ask_for_confirmation (NULL, _("Enable any purpose? [Yes]/No "), TRUE);
 		} else {
 			printf (_("* Any purpose disabled by policy\n"));
@@ -946,7 +981,7 @@ int ca_cli_callback_crlgen (int argc, char **argv)
 		return -1;
 	}
 
-	error = crl_generate (id_ca, filename);
+	error = crl_generate (id_ca, g_strdup(filename));
 
 	if (! error) {
 		printf (_("CRL generated successfully into file '%s'\n"), filename);
@@ -1126,7 +1161,11 @@ int ca_cli_callback_showcert (int argc, char **argv)
 	gchar * certificate_pem;
 	
 	TlsCert * cert = NULL;
+#ifndef WIN32
 	struct tm tim;
+#else
+	struct tm *tim = NULL;
+#endif
 	gchar model_time_str[100];
 	gchar *aux;
 	UInt160 *serial_number;
@@ -1158,12 +1197,22 @@ int ca_cli_callback_showcert (int argc, char **argv)
 	printf (_("\tUnique ID: %s\n"), (cert->issuer_key_id ? cert->issuer_key_id : _("None.")));
 	
 	printf (_("Validity:\n"));
+#ifndef WIN32
 	gmtime_r (&cert->activation_time, &tim);
 	strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &tim);	
+#else
+	tim = gmtime (&cert->activation_time);
+	strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), tim);	
+#endif
 	printf (_("\tActivated on: %s\n"), model_time_str);
 
+#ifndef WIN32
 	gmtime_r (&cert->expiration_time, &tim);
 	strftime (model_time_str, 100, _("%m/%d/%Y %R GMT"), &tim);	
+#else
+	tim = gmtime (&cert->expiration_time);
+	strftime (model_time_str, 100, _("%m/%d/%Y %H:%M GMT"), tim);	
+#endif
 	printf (_("\tExpires on: %s\n"), model_time_str);
 
 	printf (_("Fingerprints:\n"));
@@ -1224,22 +1273,23 @@ typedef enum {
 	CA_CLI_CALLBACK_POLICY_O_FORCE_SAME = 8,
 	CA_CLI_CALLBACK_POLICY_OU_FORCE_SAME = 9,
 	CA_CLI_CALLBACK_POLICY_HOURS_BETWEEN_CRL_UPDATES = 10,
-	CA_CLI_CALLBACK_POLICY_MONTHS_TO_EXPIRE = 11,
-	CA_CLI_CALLBACK_POLICY_CA = 12,
-	CA_CLI_CALLBACK_POLICY_CRL_SIGN = 13,
-	CA_CLI_CALLBACK_POLICY_NON_REPUTATION = 14,
-	CA_CLI_CALLBACK_POLICY_DIGITAL_SIGNATURE = 15,
-	CA_CLI_CALLBACK_POLICY_KEY_ENCIPHERMENT = 16,
-	CA_CLI_CALLBACK_POLICY_KEY_AGREEMENT = 17,
-	CA_CLI_CALLBACK_POLICY_DATA_ENCIPHERMENT = 18,
-	CA_CLI_CALLBACK_POLICY_TLS_WEB_SERVER = 19,
-	CA_CLI_CALLBACK_POLICY_TLS_WEB_CLIENT = 20,
-	CA_CLI_CALLBACK_POLICY_TIME_STAMPING = 21,
-	CA_CLI_CALLBACK_POLICY_CODE_SIGNING = 22,
-	CA_CLI_CALLBACK_POLICY_EMAIL_PROTECTION = 23,
-	CA_CLI_CALLBACK_POLICY_OCSP_SIGNING = 24,
-	CA_CLI_CALLBACK_POLICY_ANY_PURPOSE = 25,
-	CA_CLI_CALLBACK_POLICY_NUMBER = 26
+	CA_CLI_CALLBACK_POLICY_CRL_DISTRIBUTION_POINT = 11,
+	CA_CLI_CALLBACK_POLICY_MONTHS_TO_EXPIRE = 12,
+	CA_CLI_CALLBACK_POLICY_CA = 13,
+	CA_CLI_CALLBACK_POLICY_CRL_SIGN = 14,
+	CA_CLI_CALLBACK_POLICY_NON_REPUTATION = 15,
+	CA_CLI_CALLBACK_POLICY_DIGITAL_SIGNATURE = 16,
+	CA_CLI_CALLBACK_POLICY_KEY_ENCIPHERMENT = 17,
+	CA_CLI_CALLBACK_POLICY_KEY_AGREEMENT = 18,
+	CA_CLI_CALLBACK_POLICY_DATA_ENCIPHERMENT = 19,
+	CA_CLI_CALLBACK_POLICY_TLS_WEB_SERVER = 20,
+	CA_CLI_CALLBACK_POLICY_TLS_WEB_CLIENT = 21,
+	CA_CLI_CALLBACK_POLICY_TIME_STAMPING = 22,
+	CA_CLI_CALLBACK_POLICY_CODE_SIGNING = 23,
+	CA_CLI_CALLBACK_POLICY_EMAIL_PROTECTION = 24,
+	CA_CLI_CALLBACK_POLICY_OCSP_SIGNING = 25,
+	CA_CLI_CALLBACK_POLICY_ANY_PURPOSE = 26,
+	CA_CLI_CALLBACK_POLICY_NUMBER = 27
 } CaCallbackPolicy;
 
 static gchar *CaCallbackPolicyName[CA_CLI_CALLBACK_POLICY_NUMBER] = {
@@ -1254,6 +1304,7 @@ static gchar *CaCallbackPolicyName[CA_CLI_CALLBACK_POLICY_NUMBER] = {
 	"O_FORCE_SAME",
 	"OU_FORCE_SAME",
 	"HOURS_BETWEEN_CRL_UPDATES",
+	"CRL_DISTRIBUTION_POINT",
 	"MONTHS_TO_EXPIRE",
 	"CA",
 	"CRL_SIGN",
@@ -1283,6 +1334,7 @@ static gchar *CaCallbackPolicyDescriptions[CA_CLI_CALLBACK_POLICY_NUMBER] = {
 	N_("Organization in generated certs must be the same than in CA       "),
 	N_("Organizational Unit in generated certs must be the same than in CA"),
 	N_("Maximum number of hours between CRL updates                       "),
+	N_("CRL distribution point (URL where CRL is published)               "),
 	N_("Maximum number of months before expiration of new certs           "),
 	N_("CA use enabled in generated certs                                 "),
 	N_("CRL Sign use enabled in generated certs                           "),
@@ -1318,7 +1370,7 @@ int ca_cli_callback_showpolicy (int argc, char **argv)
 	printf (_("Id.\tDescription\t\t\t\t\t\t\t\tValue\n"));
 	for (i = 0; i < CA_CLI_CALLBACK_POLICY_NUMBER; i++) {
 
-		printf ("%d\t%s\t%d\n", i, CaCallbackPolicyDescriptions[i], ca_file_policy_get(ca_id, CaCallbackPolicyName[i]));
+		printf ("%d\t%s\t%s\n", i, CaCallbackPolicyDescriptions[i], ca_file_policy_get(ca_id, CaCallbackPolicyName[i]));
 
 	}
 
@@ -1330,12 +1382,12 @@ int ca_cli_callback_setpolicy (int argc, char **argv)
 {
 	guint64 ca_id = atoll(argv[1]);
 	gint policy_id = atoi (argv[2]);
-	gint value = atoi (argv[3]);
+	gchar *value = argv[3];
 	gchar *message = NULL;
 	gchar *description = NULL;
 	gint i;
 
-	if (! ca_file_check_if_is_csr_id (ca_id)) {
+	if (! ca_file_check_if_is_ca_id (ca_id)) {
 		dialog_error (_("The given CA id. is not valid"));
 		return -1;
 	}
@@ -1353,16 +1405,16 @@ int ca_cli_callback_setpolicy (int argc, char **argv)
 		}
 	}
 
-	message = g_strdup_printf (_("You are about to assign to the policy\n'%s' the new value '%d'."), description, value);
+	message = g_strdup_printf (_("You are about to assign to the policy\n'%s' the new value '%s'."), description, value);
 	g_free (description);
 
 
 	if (dialog_ask_for_confirmation (message, _("Are you sure? Yes/[No] : "), FALSE)) {
-		if (! ca_file_policy_set (ca_id, CaCallbackPolicyName[i], value)) {
+		if (! ca_file_policy_set (ca_id, CaCallbackPolicyName[policy_id], value)) {
 			g_free (message);
 			return -1;
 		} else
-			printf (_("Policy set correctly to '%d'.\n"), value);
+			printf (_("Policy set correctly to '%s'.\n"), value);
 			
 		
 	} else {
