@@ -191,7 +191,7 @@ void __new_cert_populate_ca_treeview (GtkTreeView *treeview)
 
 }
 
-void new_cert_signing_ca_treeview_cursor_changed (GtkTreeView *treeview, gpointer userdata)
+G_MODULE_EXPORT void new_cert_signing_ca_treeview_cursor_changed (GtkTreeView *treeview, gpointer userdata)
 {
         GtkTreeSelection *selection = gtk_tree_view_get_selection (treeview);
         if (gtk_tree_selection_count_selected_rows(selection) == 0)
@@ -288,7 +288,7 @@ void new_cert_tab_activate (int tab_number)
 
 }
 
-void on_new_cert_next2_clicked (GtkButton *button,
+G_MODULE_EXPORT void on_new_cert_next2_clicked (GtkButton *button,
 			      gpointer user_data) 
 {
 	// Whenever gnoMint support more than one CA, here we will
@@ -319,31 +319,31 @@ void on_new_cert_next2_clicked (GtkButton *button,
         g_free (value);
 	
         /* Check for differences in fields that must be equal according to the CA policy */
-        if (ca_file_policy_get (ca_id, "C_FORCE_SAME") && 
+        if (ca_file_policy_get_int (ca_id, "C_FORCE_SAME") && 
             (tls_ca_cert->c != tls_csr->c) && // If they are the same, they both are NULL, so it is OK
             (tls_ca_cert->c == NULL || tls_csr->c == NULL || strcmp(tls_ca_cert->c, tls_csr->c))) {
                 dialog_error (_("The policy of this CA obligue the country field of the certificates to be the same as the one in the CA cert."));
                 return;
         }
-        if (ca_file_policy_get (ca_id, "ST_FORCE_SAME") && 
+        if (ca_file_policy_get_int (ca_id, "ST_FORCE_SAME") && 
             (tls_ca_cert->st != tls_csr->st) && // If they are the same, they both are NULL, so it is OK
             (tls_ca_cert->st == NULL || tls_csr->st == NULL || strcmp(tls_ca_cert->st, tls_csr->st))) {
                 dialog_error (_("The policy of this CA obligue the state/province field of the certificates to be the same as the one in the CA cert."));
                 return;
         }
-        if (ca_file_policy_get (ca_id, "L_FORCE_SAME") && 
+        if (ca_file_policy_get_int (ca_id, "L_FORCE_SAME") && 
             (tls_ca_cert->l != tls_csr->l) && // If they are the same, they both are NULL, so it is OK
             (tls_ca_cert->l == NULL || tls_csr->st == NULL || strcmp(tls_ca_cert->l, tls_csr->l))) {
                 dialog_error (_("The policy of this CA obligue the locality/city field of the certificates to be the same as the one in the CA cert."));
                 return;
         }
-        if (ca_file_policy_get (ca_id, "O_FORCE_SAME") && 
+        if (ca_file_policy_get_int (ca_id, "O_FORCE_SAME") && 
             (tls_ca_cert->o != tls_csr->o) && // If they are the same, they both are NULL, so it is OK
             (tls_ca_cert->o == NULL || tls_csr->o == NULL || strcmp(tls_ca_cert->o, tls_csr->o))) {
                 dialog_error (_("The policy of this CA obligue the organization field of the certificates to be the same as the one in the CA cert."));
                 return;
         }
-        if (ca_file_policy_get (ca_id, "OU_FORCE_SAME") && 
+        if (ca_file_policy_get_int (ca_id, "OU_FORCE_SAME") && 
             (tls_ca_cert->ou != tls_csr->ou) && // If they are the same, they both are NULL, so it is OK
             (tls_ca_cert->ou == NULL || tls_csr->ou == NULL || strcmp(tls_ca_cert->ou, tls_csr->ou))) {
                 dialog_error (_("The policy of this CA obligue the organizational unit field of the certificates to be the same as the one in the CA cert."));
@@ -354,79 +354,79 @@ void on_new_cert_next2_clicked (GtkButton *button,
 
         tls_cert_free (tls_ca_cert);
 
-	i_value = ca_file_policy_get (ca_id, "MONTHS_TO_EXPIRE");
+	i_value = ca_file_policy_get_int (ca_id, "MONTHS_TO_EXPIRE");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "months_before_expiration_spinbutton1");
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON(object), 1, i_value);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "CA");
+	i_value = ca_file_policy_get_int (ca_id, "CA");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "ca_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 
-/* 	i_value = ca_file_policy_get (ca_id, "CERT_SIGN")); */
+/* 	i_value = ca_file_policy_get_int (ca_id, "CERT_SIGN")); */
 /* 	object = gtk_builder_get_object (new_cert_window_gtkb, "cert_signing_check2"); */
 /* 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value); */
 
-	i_value = ca_file_policy_get (ca_id, "CRL_SIGN");
+	i_value = ca_file_policy_get_int (ca_id, "CRL_SIGN");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "crl_signing_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "NON_REPUDIATION");
+	i_value = ca_file_policy_get_int (ca_id, "NON_REPUDIATION");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "non_repudiation_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "DIGITAL_SIGNATURE");
+	i_value = ca_file_policy_get_int (ca_id, "DIGITAL_SIGNATURE");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "digital_signature_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "KEY_ENCIPHERMENT");
+	i_value = ca_file_policy_get_int (ca_id, "KEY_ENCIPHERMENT");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "key_encipherment_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "KEY_AGREEMENT");
+	i_value = ca_file_policy_get_int (ca_id, "KEY_AGREEMENT");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "key_agreement_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "DATA_ENCIPHERMENT");
+	i_value = ca_file_policy_get_int (ca_id, "DATA_ENCIPHERMENT");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "data_encipherment_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "TLS_WEB_SERVER");
+	i_value = ca_file_policy_get_int (ca_id, "TLS_WEB_SERVER");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "webserver_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "TLS_WEB_CLIENT");
+	i_value = ca_file_policy_get_int (ca_id, "TLS_WEB_CLIENT");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "webclient_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "TIME_STAMPING");
+	i_value = ca_file_policy_get_int (ca_id, "TIME_STAMPING");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "time_stamping_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "CODE_SIGNING");
+	i_value = ca_file_policy_get_int (ca_id, "CODE_SIGNING");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "code_signing_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "EMAIL_PROTECTION");
+	i_value = ca_file_policy_get_int (ca_id, "EMAIL_PROTECTION");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "email_protection_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 	
-	i_value = ca_file_policy_get (ca_id, "OCSP_SIGNING");
+	i_value = ca_file_policy_get_int (ca_id, "OCSP_SIGNING");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "ocsp_signing_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
 
-	i_value = ca_file_policy_get (ca_id, "ANY_PURPOSE");
+	i_value = ca_file_policy_get_int (ca_id, "ANY_PURPOSE");
 	object = gtk_builder_get_object (new_cert_window_gtkb, "any_purpose_check");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(object), i_value);
 	gtk_widget_set_sensitive (GTK_WIDGET(object), i_value);
@@ -435,26 +435,26 @@ void on_new_cert_next2_clicked (GtkButton *button,
 	new_cert_tab_activate (2);
 }
 
-void on_new_cert_previous2_clicked (GtkButton *widget,
+G_MODULE_EXPORT void on_new_cert_previous2_clicked (GtkButton *widget,
 				  gpointer user_data) 
 {
 	new_cert_tab_activate (0);
 }
 
-void on_new_cert_next1_clicked (GtkButton *button,
+G_MODULE_EXPORT void on_new_cert_next1_clicked (GtkButton *button,
 			      gpointer user_data) 
 {
 
 	new_cert_tab_activate (1);
 }
 
-void on_new_cert_previous3_clicked (GtkButton *widget,
+G_MODULE_EXPORT void on_new_cert_previous3_clicked (GtkButton *widget,
 				  gpointer user_data) 
 {
 	new_cert_tab_activate (1);
 }
 
-void on_new_cert_cancel_clicked (GtkButton *widget,
+G_MODULE_EXPORT void on_new_cert_cancel_clicked (GtkButton *widget,
 			       gpointer user_data) 
 {
 	GtkWidget * window = GTK_WIDGET(gtk_builder_get_object (new_cert_window_gtkb, "new_cert_window"));
@@ -462,7 +462,7 @@ void on_new_cert_cancel_clicked (GtkButton *widget,
 	
 }
 
-void on_new_cert_property_toggled (GtkWidget *button, gpointer user_data)
+G_MODULE_EXPORT void on_new_cert_property_toggled (GtkWidget *button, gpointer user_data)
 {
         gboolean is_active;
 	
@@ -677,7 +677,7 @@ void on_new_cert_property_toggled (GtkWidget *button, gpointer user_data)
         
 }
 
-void on_new_cert_commit_clicked (GtkButton *widg,
+G_MODULE_EXPORT void on_new_cert_commit_clicked (GtkButton *widg,
 				 gpointer user_data) 
 {
 	GtkTreeView *treeview = GTK_TREE_VIEW(gtk_builder_get_object(new_cert_window_gtkb, "signing_ca_treeview"));
@@ -736,6 +736,8 @@ void on_new_cert_commit_clicked (GtkButton *widg,
 	widget = gtk_builder_get_object (new_cert_window_gtkb, "any_purpose_check");
 	cert_creation_data->any_purpose = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget));
 
+	cert_creation_data->crl_distribution_point = ca_file_policy_get (ca_id, "CRL_DISTRIBUTION_POINT");
+
 	strerror = new_cert_sign_csr (csr_id, ca_id, cert_creation_data);
 
 	if (strerror) {
@@ -768,13 +770,19 @@ const gchar *new_cert_sign_csr (guint64 csr_id, guint64 ca_id, TlsCertCreationDa
 	tmp = time (NULL);	
 	cert_creation_data->activation = tmp;
 	
+#ifndef WIN32
 	expiration_time = g_new (struct tm,1);
-	localtime_r (&tmp, expiration_time);      
+	localtime_r (&tmp, expiration_time);
+#else
+	expiration_time = localtime(&tmp);
+#endif
 	expiration_time->tm_mon = expiration_time->tm_mon + cert_creation_data->key_months_before_expiration;
 	expiration_time->tm_year = expiration_time->tm_year + (expiration_time->tm_mon / 12);
 	expiration_time->tm_mon = expiration_time->tm_mon % 12;		
 	cert_creation_data->expiration = mktime(expiration_time);
+#ifndef WIN32
 	g_free (expiration_time);
+#endif
 
         ca_file_get_next_serial (&cert_creation_data->serial, ca_id);
 
