@@ -516,6 +516,10 @@ gchar * tls_generate_self_signed_certificate (TlsCreationData * creation_data,
 		return g_strdup_printf(_("Error when setting keyUsage extension"));
 	}
 
+	if (creation_data->crl_distribution_point) {
+		gnutls_x509_crt_set_crl_dist_points (crt, GNUTLS_SAN_URI, creation_data->crl_distribution_point, 0);
+	}
+
 	keyid = g_new0 (guchar,1);	
 	gnutls_x509_crt_get_key_id(crt, 0, keyid, &keyidsize);
 	g_free (keyid);
@@ -534,7 +538,7 @@ gchar * tls_generate_self_signed_certificate (TlsCreationData * creation_data,
 
 	// __add_ext (certificate, NID_netscape_cert_type, "sslCA");
 	//
-	// __add_ext (certificate, NID_netscape_comment, "Generated by gnoMint, by David Marin");
+	//__add_ext (certificate, NID_netscape_comment, "gnoMint Generated Certificate");
 
 	if (gnutls_x509_crt_sign(crt, crt, (* key))) {
 		gnutls_x509_crt_deinit (crt);
@@ -832,6 +836,12 @@ gchar * tls_generate_certificate (TlsCertCreationData * creation_data,
 		gnutls_x509_crt_set_key_purpose_oid (crt, GNUTLS_KP_ANY, FALSE);
 
 
+	if (creation_data->crl_distribution_point && creation_data->crl_distribution_point[0])
+		gnutls_x509_crt_set_crl_dist_points (crt, GNUTLS_SAN_URI, creation_data->crl_distribution_point, 0);
+	else
+		gnutls_x509_crt_cpy_crl_dist_points (crt, ca_crt);
+		
+
 	if (gnutls_x509_crt_sign(crt, ca_crt, ca_pkey)) {
 		gnutls_x509_crq_deinit (csr);
 		gnutls_x509_crt_deinit (crt);
@@ -872,6 +882,7 @@ TlsCert * tls_parse_cert_pem (const char * pem_certificate)
 	guint key_usage;
 	gint i;
 	guint critical;
+	guint aux_uint;
 	
 	size_t size;
 
@@ -1099,6 +1110,17 @@ TlsCert * tls_parse_cert_pem (const char * pem_certificate)
 	g_free (uaux);
 	uaux = NULL;
 
+	size = 0;
+	gnutls_x509_crt_get_crl_dist_points (*cert, 0, aux, &size, &aux_uint, &critical);
+	if (size) {
+		aux = g_new0(gchar, size);
+		if (gnutls_x509_crt_get_crl_dist_points (*cert, 0, aux, &size, &aux_uint, &critical) == GNUTLS_SAN_URI &&
+		    aux_uint == 0)
+			res->crl_distribution_point = g_strdup (aux);
+		g_free (aux);
+		aux = NULL;
+	}
+
 
 	size = 0;
 	gnutls_x509_crt_get_subject_key_id (*cert, uaux, &size, NULL);
@@ -1180,6 +1202,7 @@ void tls_cert_free (TlsCert *tlscert)
 	g_free (tlscert->sha1);
 	g_free (tlscert->md5);
 	g_free (tlscert->key_id);
+        g_free (tlscert->crl_distribution_point);
 
 	g_free (tlscert);
 }
@@ -1616,8 +1639,13 @@ void tls_creation_data_free (TlsCreationData *cd)
 		g_free (cd->emailAddress);
 	if (cd->password)
 		g_free (cd->password);
+        if (cd->crl_distribution_point)
+                g_free (cd->crl_distribution_point);
         if (cd->parent_ca_id_str)
                 g_free (cd->parent_ca_id_str);
+	if (cd->crl_distribution_point)
+		g_free (cd->crl_distribution_point);
+
 	g_free (cd);
 }
 
